// $Id: zeitgeist.js,v 1.1.4.3 2011/01/05 17:40:24 fgm Exp $

/**
 * @file
 * Separator choice for inline displays on the settings form.
 *
 * This file is only included on the settings form, nowhere else, so we can use
 * comparatively simple selectors and be reasonably confident they will not be
 * matching anywhere else.
 *
 * @copyright (c) 2010-2011 Ouest Systemes Informatiques (OSInet)
 *
 * @author Frederic G. MARAND <fgm@osinet.fr>
 *
 * @license Licensed under the CeCILL version 2 and GPL version 2 or later
 *
 * License note: G2 is distributed by OSInet to its customers under the
 * CeCILL 2.0 license. OSInet support services only apply to the module
 * when distributed by OSInet, not by any third-party further down the
 * distribution chain.
 *
 * If you obtained G2 from drupal.org, that site received it under the
 * GPL v2 or later license and can therefore distribute it under the
 * GPL v2 or later, and so can you and just anyone down the chain as
 * long as the GPL v2 or later terms are abided by, the module
 * distributor in that case being the drupal.org organization or the
 * downstream distributor, not OSInet.
 */

/*jslint white: true, onevar: true, undef: true, nomen: true, eqeqeq: true,
  plusplus: true, bitwise: true, regexp: true, newcap: true, immed: true,
  indent: 2 */
/*global jQuery */

/**
 * Fade a selection in or out, depending on the parameters
 *
 * jQuery().toggle(visibility) behaves too erratically, hence the separate show/hide
 * calls.
 *
 * @param string selector
 *   A jQuery selector
 * @param boolean visible
 *   Set to true to fade in, to fase to fade out
 * @return void
 */
function zeitgeistFade(selector, visible) {
  if (visible) {
    jQuery(selector).show();
  }
  else {
    jQuery(selector).hide();
  }
}

/**
 * Ready handler to apply visibility to the separator fields on
 * _zeitgeist_admin_settings_form.
 *
 * Hide the separator field initially unless the current display mode is set
 * to manual for the matching block (top/latest).
 *
 * @return void
 */
function zeitgeistOnSeparatorVisibility() {
  zeitgeistFade('.form-item-zeitgeist-top-sep',
    jQuery("input:radio[name='zeitgeist_top_display']:checked").val() === 'implode');

  jQuery("input:radio[name='zeitgeist_top_display']").click(function () {
    zeitgeistFade('.form-item-zeitgeist-top-sep',
      jQuery("input:radio[name='zeitgeist_top_display']:checked").val() === 'implode');
  });

  zeitgeistFade('.form-item-zeitgeist-latest-sep',
    jQuery("input:radio[name='zeitgeist_latest_display']:checked").val() === 'implode');

  jQuery("input:radio[name='zeitgeist_latest_display']").click(function () {
    zeitgeistFade('.form-item-zeitgeist-latest-sep',
      jQuery("input:radio[name='zeitgeist_latest_display']:checked").val() === 'implode');
  });
}

/**
 * Assign ready handlers
 */
jQuery(function () {
  zeitgeistOnSeparatorVisibility();
});
